# fastbook libraries
> Simple installer for everything needed for fastbook

## Installing

To install everything needed for the fastbook, you can run:
``` 
conda install -c fastai -c pytorch fastbook
```

or alternatively (if you've already got PyTorch installed):

```
pip install fastbook
```

## Develop

Development of this lib requires [nbdev](https://nbdev.fast.ai). Users of this lib do not require nbdev, however.
